@@ -1,10 +1,5 @@
 package App::CekBpom;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-02-19'; # DATE
-our $DIST = 'App-CekBpom'; # DIST
-our $VERSION = '0.013'; # VERSION
-
 use 5.010001;
 use strict 'subs', 'vars';
 use warnings;
@@ -12,6 +7,11 @@ use Log::ger;
 
 use Time::HiRes qw(time);
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-10-01'; # DATE
+our $DIST = 'App-CekBpom'; # DIST
+our $VERSION = '0.014'; # VERSION
+
 use Exporter qw(import);
 our @EXPORT_OK = qw(cek_bpom_products);
 
@@ -385,7 +385,7 @@ App::CekBpom - Check BPOM products/manufacturers ("sarana") via the command-line
 
 =head1 VERSION
 
-This document describes version 0.013 of App::CekBpom (from Perl distribution App-CekBpom), released on 2021-02-19.
+This document describes version 0.014 of App::CekBpom (from Perl distribution App-CekBpom), released on 2021-10-01.
 
 =head1 DESCRIPTION
 
@@ -398,7 +398,7 @@ See included script L<cek-bpom-products> and L<cek-bpom-manufacturers>.
 
 Usage:
 
- cek_bpom_products(%args) -> [status, msg, payload, meta]
+ cek_bpom_products(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Search BPOM products via https:E<sol>E<sol>cekbpom.pom.go.idE<sol>.
 
@@ -408,7 +408,7 @@ Examples:
 
 =item * By default search against name (nama_produk) and brand (merk):
 
- cek_bpom_products( queries => ["hichew", "hi-chew", "hi chew"]);
+ cek_bpom_products(queries => ["hichew", "hi-chew", "hi chew"]);
 
 =back
 
@@ -502,12 +502,12 @@ manufacturer (see C<--get-product-detail> option).
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -519,14 +519,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-CekBpo
 
 Source repository is at L<https://github.com/perlancar/perl-App-CekBpom>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-App-CekBpom/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<https://cekbpom.pom.go.id/>
@@ -535,11 +527,36 @@ L<https://cekbpom.pom.go.id/>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-CekBpom>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
